@@ -5,11 +5,9 @@ from typing import (Optional,
                     TypeVar)
 
 from reprit.base import generate_repr
-from robust.linear import (SegmentsRelationship,
-                           segments_intersection)
+from robust.linear import SegmentsRelationship
 
-from orient.hints import (Coordinate,
-                          Point,
+from orient.hints import (Point,
                           Segment)
 
 
@@ -39,63 +37,37 @@ class LinearEvent:
     def end(self) -> Point:
         return self.complement.start
 
-    def set_both_relationships(self, relationship: SegmentsRelationship
-                               ) -> None:
-        self.relationship = self.complement.relationship = relationship
-
-    @property
-    def is_vertical(self) -> bool:
-        start_x, _ = self.start
-        end_x, _ = self.end
-        return start_x == end_x
-
-    @property
-    def is_horizontal(self) -> bool:
-        _, start_y = self.start
-        _, end_y = self.end
-        return start_y == end_y
-
     @property
     def segment(self) -> Segment:
         return self.start, self.end
 
-    def y_at(self, x: Coordinate) -> Coordinate:
-        if self.is_vertical or self.is_horizontal:
-            _, start_y = self.start
-            return start_y
-        else:
-            start_x, start_y = self.start
-            if x == start_x:
-                return start_y
-            end_x, end_y = self.end
-            if x == end_x:
-                return end_y
-            _, result = segments_intersection(self.segment,
-                                              ((x, start_y), (x, end_y)))
-            return result
+    def set_both_relationships(self, relationship: SegmentsRelationship
+                               ) -> None:
+        self.relationship = self.complement.relationship = relationship
 
 
 @unique
-class OverlapTransition(IntEnum):
+class OverlapOrientation(IntEnum):
     NONE = 0
     SAME = 1
     DIFFERENT = 2
 
 
 class CompoundEvent(LinearEvent):
-    __slots__ = 'overlap_transition', 'in_out', 'other_in_out'
+    __slots__ = 'overlap_orientation', 'inside_on_left', 'other_inside_on_left'
 
     def __init__(self,
                  is_left_endpoint: bool,
                  start: Point,
                  complement: Optional['CompoundEvent'],
                  from_test: bool,
-                 relationship: SegmentsRelationship) -> None:
+                 relationship: SegmentsRelationship,
+                 inside_on_left: bool) -> None:
         super().__init__(is_left_endpoint, start, complement, from_test,
                          relationship)
-        self.overlap_transition = OverlapTransition.NONE
-        self.in_out = None
-        self.other_in_out = None
+        self.overlap_orientation = OverlapOrientation.NONE
+        self.inside_on_left = inside_on_left
+        self.other_inside_on_left = False
 
     @property
     def common_boundary(self) -> bool:
@@ -103,14 +75,14 @@ class CompoundEvent(LinearEvent):
         Checks if the segment lies on the boundary of the components
         which intersect in region.
         """
-        return self.overlap_transition is OverlapTransition.SAME
+        return self.overlap_orientation is OverlapOrientation.SAME
 
     @property
     def contours_overlap(self) -> bool:
         """
         Checks if the segment is a separate component of the intersection.
         """
-        return self.overlap_transition is OverlapTransition.DIFFERENT
+        return self.overlap_orientation is OverlapOrientation.DIFFERENT
 
     @property
     def inside(self) -> bool:
@@ -118,8 +90,8 @@ class CompoundEvent(LinearEvent):
         Checks if the segment enclosed by
         or lies within the region of the intersection.
         """
-        return (not self.other_in_out
-                and self.overlap_transition is OverlapTransition.NONE)
+        return (self.other_inside_on_left
+                and self.overlap_orientation is OverlapOrientation.NONE)
 
     @property
     def outside(self) -> bool:
@@ -127,8 +99,8 @@ class CompoundEvent(LinearEvent):
         Checks if the segment touches
         or disjoint with the region of the intersection.
         """
-        return (self.other_in_out
-                and self.overlap_transition is OverlapTransition.NONE)
+        return (not self.other_inside_on_left
+                and self.overlap_orientation is OverlapOrientation.NONE)
 
 
 Event = TypeVar('Event', LinearEvent, CompoundEvent)
