@@ -73,8 +73,8 @@ class CompoundSweeper(Sweeper[CompoundEvent]):
         for start, end in segments:
             inside_on_left = True
             if start > end:
-                inside_on_left = False
                 start, end = end, start
+                inside_on_left = False
             start_event = self.event_cls(True, start, None, from_test,
                                          SegmentsRelationship.NONE,
                                          inside_on_left)
@@ -101,13 +101,11 @@ class CompoundSweeper(Sweeper[CompoundEvent]):
         events_queue = self._events_queue
         while events_queue:
             event = events_queue.peek()
-            start = event.start
-            start_x, _ = start
+            start_x, _ = start = event.start
             if start_x > stop_x:
                 # no intersection segments left
                 return
             events_queue.pop()
-            sweep_line.move_to(start_x)
             same_start_events = [event]
             while events_queue and events_queue.peek().start == start:
                 same_start_events.append(events_queue.pop())
@@ -153,24 +151,22 @@ class CompoundSweeper(Sweeper[CompoundEvent]):
             if event.from_test is below_event.from_test:
                 raise ValueError('Segments of the same object '
                                  'should not overlap.')
-
-            starts_equal = event.start == below_event.start
-            if starts_equal:
-                start_min = start_max = None
-            elif EventsQueueKey(event) < EventsQueueKey(below_event):
-                start_min, start_max = event, below_event
-            else:
-                start_min, start_max = below_event, event
-
-            ends_equal = event.end == below_event.end
-            if ends_equal:
-                end_min = end_max = None
-            elif (EventsQueueKey(event.complement)
-                  < EventsQueueKey(below_event.complement)):
-                end_min, end_max = event.complement, below_event.complement
-            else:
-                end_min, end_max = below_event.complement, event.complement
-
+            starts_equal = below_event.start == event.start
+            ends_equal = below_event.end == event.end
+            start_min, start_max = ((None, None)
+                                    if starts_equal
+                                    else ((event, below_event)
+                                          if (EventsQueueKey(event)
+                                              < EventsQueueKey(below_event))
+                                          else (below_event, event)))
+            end_min, end_max = ((None, None)
+                                if ends_equal
+                                else
+                                ((event.complement, below_event.complement)
+                                 if (EventsQueueKey(event.complement)
+                                     < EventsQueueKey(below_event.complement))
+                                 else (below_event.complement,
+                                       event.complement)))
             if starts_equal:
                 # both line segments are equal or share the left endpoint
                 below_event.overlap_orientation = event.overlap_orientation = (
@@ -266,13 +262,11 @@ class LinearSweeper(Sweeper[LinearEvent]):
         prev_from_other_events = []  # type: List[LinearEvent]
         while events_queue:
             event = events_queue.peek()
-            start = event.start
-            start_x, _ = start
+            start_x, _ = start = event.start
             if start_x > stop_x:
                 # no intersection segments left
                 return
             events_queue.pop()
-            sweep_line.move_to(start_x)
             same_start_events = [event]
             from_same_events, from_other_events = (
                 ((prev_from_same_events + [event], prev_from_other_events)
@@ -346,24 +340,22 @@ class LinearSweeper(Sweeper[LinearEvent]):
             if event.from_test is below_event.from_test:
                 raise ValueError('Segments of the same object '
                                  'should not overlap.')
-
-            starts_equal = event.start == below_event.start
-            if starts_equal:
-                start_min = start_max = None
-            elif EventsQueueKey(event) < EventsQueueKey(below_event):
-                start_min, start_max = event, below_event
-            else:
-                start_min, start_max = below_event, event
-
-            ends_equal = event.end == below_event.end
-            if ends_equal:
-                end_min = end_max = None
-            elif (EventsQueueKey(event.complement)
-                  < EventsQueueKey(below_event.complement)):
-                end_min, end_max = event.complement, below_event.complement
-            else:
-                end_min, end_max = below_event.complement, event.complement
-
+            starts_equal = below_event.start == event.start
+            ends_equal = below_event.end == event.end
+            start_min, start_max = ((None, None)
+                                    if starts_equal
+                                    else ((event, below_event)
+                                          if (EventsQueueKey(event)
+                                              < EventsQueueKey(below_event))
+                                          else (below_event, event)))
+            end_min, end_max = ((None, None)
+                                if ends_equal
+                                else
+                                ((event.complement, below_event.complement)
+                                 if (EventsQueueKey(event.complement)
+                                     < EventsQueueKey(below_event.complement))
+                                 else (below_event.complement,
+                                       event.complement)))
             if starts_equal:
                 # both line segments are equal or share the left endpoint
                 if ends_equal:
@@ -402,7 +394,6 @@ class LinearSweeper(Sweeper[LinearEvent]):
                     self.divide_segment(below_event, point)
                 if point != event.start and point != event.end:
                     self.divide_segment(event, point)
-
             if event.from_test is not below_event.from_test:
                 event.set_both_relationships(max(event.relationship,
                                                  relationship))
